@@ -56,14 +56,25 @@ class Actor:
     props: Props = Props()
     state: bool = False
     power: int = 100
+    timer: int = 0
     type: str = None
     instance: str = None
 
     def __str__(self):
-        return "name={} props={}, state={}, type={}, power={}".format(self.name, self.props, self.state, self.type, self.power)
+        return "name={} props={}, state={}, type={}, power={}, timer={}".format(self.name, self.props, self.state, self.type, self.power, self.timer)
     def to_dict(self):
-        return dict(id=self.id, name=self.name, type=self.type, props=self.props.to_dict(), state=self.instance.get_state(), power=self.power)
+        if self.instance is not None:
+            state = self.instance.get_state()
+            actortype = self.type
+        else:
+            state = False
+            actortype = self.type # !!! MISSING TYPE !!!
+        return dict(id=self.id, name=self.name, type=actortype, props=self.props.to_dict(), state=state, power=self.power, timer=self.timer)
 
+class DataType(Enum):
+    VALUE="value"
+    DATETIME="datetime"
+    STRING="string"
 
 @dataclass
 class Sensor:
@@ -73,7 +84,10 @@ class Sensor:
     state: bool = False
     type: str = None
     instance: str = None
-
+    datatype: DataType = DataType.VALUE
+    inrange: bool = True
+    temp_range: float = 0
+    
     def __str__(self):
         return "name={} props={}, state={}".format(self.name, self.props, self.state)
     def to_dict(self):
@@ -193,12 +207,13 @@ class Config:
     value: Any = None
     description: str = None
     type: ConfigType = ConfigType.STRING
+    source: str = None
     options: Any = None
 
     def __str__(self):
         return "....name={} value={}".format(self.name, self.value)
     def to_dict(self):  
-        return dict(name=self.name, value=self.value, type=self.type.value, description=self.description, options=self.options)
+        return dict(name=self.name, value=self.value, type=self.type.value, description=self.description, source=self.source, options=self.options)
 
 @dataclass  
 class NotificationAction:
