@@ -67,6 +67,16 @@ class ActorController(BasicController):
         except Exception as e:
             logging.error("Failed to update Actor {} {}".format(id, e))
 
+    async def timeractor_update(self, id, timer):
+        try:
+            item = self.find_by_id(id)
+            item.timer = round(timer)
+            #await self.push_udpate()
+            self.cbpi.ws.send(dict(topic=self.update_key, data=list(map(lambda item: item.to_dict(), self.data))))
+            self.cbpi.push_update("cbpi/actorupdate/{}".format(id), item.to_dict())
+        except Exception as e:
+            logging.error("Failed to update Actor {} {}".format(id, e))
+
     async def ws_actor_update(self):
         try:
             #await self.push_udpate()
