@@ -1,6 +1,7 @@
 import logging
 import os
 import shutil
+import pkgutil
 import psutil
 import pathlib
 import json
@@ -12,6 +13,17 @@ from cbpi.api.config import ConfigType
 from cbpi.api import *
 import zipfile
 import socket
+import importlib
+from tabulate import tabulate
+from datetime import datetime, timedelta, date
+import glob
+
+try:
+    from systemd import journal
+    systemd_available=True
+except Exception:
+    logging.warning("Failed to load systemd library. logfile download not available")
+    systemd_available=False
 
 class SystemController:
 
@@ -19,6 +31,7 @@ class SystemController:
         self.cbpi = cbpi
         self.service = cbpi.actor
         self.logger = logging.getLogger(__name__)
+        self.logsFolderPath = self.cbpi.config_folder.logsFolderPath
 
         self.cbpi.app.on_startup.append(self.check_for_update)
 
@@ -37,9 +50,42 @@ class SystemController:
         pass
 
     async def backupConfig(self):
-        output_filename = "cbpi4_config"
+        files=glob.glob('*cbpi4_config*.zip')
+        for f in files:
+            try:
+                os.remove(f)
+            except Exception as e:
+                logging.error("Cannot remove old config backup: {}".format(e))
+
+        try:
+            current_date = date.today()
+            current_date=str(current_date).replace("-","_")
+            output_filename = current_date+"_cbpi4_config"
+        except:
+            output_filename = "cbpi4_config"
         dir_name = pathlib.Path(self.cbpi.config_folder.get_file_path(''))
         shutil.make_archive(output_filename, 'zip', dir_name)
+        return output_filename+".zip"
+
+    async def plugins_list(self): 
+        result = []
+        discovered_plugins = {
+            name: importlib.import_module(name)
+            for finder, name, ispkg
+            in pkgutil.iter_modules()
+            if name.startswith('cbpi') and len(name) > 4
+        }
+        for key, module in discovered_plugins.items():
+            from importlib.metadata import version
+            try:
+                from importlib.metadata import (distribution, metadata,
+                                                    version)
+                meta = metadata(key)
+                result.append(dict(Name=meta["Name"], Version=meta["Version"], Author=meta["Author"], Homepage=meta["Home-page"], Summary=meta["Summary"]))
+                            
+            except Exception as e:
+                print(e)
+        return tabulate(result, headers="keys")
 
     async def downloadlog(self, logtime):
         filename = "cbpi4.log"
@@ -54,13 +100,37 @@ class SystemController:
         fullkettlename = pathlib.Path(os.path.join(".",kettlename))
 
         output_filename="cbpi4_log.zip"
+        result=[]
+        if systemd_available:
+            j = journal.Reader()
+            if logtime == "b":
+                j.this_boot()
+            else:
+                since = datetime.now() - timedelta(hours=int(logtime))
+                j.seek_realtime(since)
+            j.add_match(_SYSTEMD_UNIT="craftbeerpi.service")
 
-        if logtime == "b":
-            os.system('journalctl -b -u craftbeerpi.service > {}'.format(fullname))
+            for entry in j:
+                result.append(entry['MESSAGE'])
         else:
-            os.system('journalctl --since \"{} hours ago\" -u craftbeerpi.service > {}'.format(logtime, fullname))
+            try:
+                logfilename=pathlib.Path(self.logsFolderPath+"/"+"cbpi.log")
+                with open(logfilename) as f:
+                    for line in f:
+                        result.append(line.rstrip('\n'))
+            except:
+                pass
+            
+        try:
+            with open(fullname, 'w') as f:
+                for line in result:
+                    f.write(f"{line}\n")
+        except Exception as e:
+            logging.error(e)
 
-        os.system('cbpi plugins > {}'.format(fullpluginname))
+        plugins = await self.plugins_list()
+        with open(fullpluginname, 'w') as f:
+            f.write(plugins)
 
         try:
             actors = self.cbpi.actor.get_state()
@@ -116,8 +186,8 @@ class SystemController:
             try:
                 content = backup_file.read()
                 if backup_file and self.allowed_file(filename, 'zip'):
-                    self.path = os.path.join(".", "restored_config.zip")
-
+                    self.path = os.path.join(self.cbpi.config_folder.configFolderPath, "restored_config.zip")
+                    
                     f=open(self.path, "wb")
                     f.write(content)
                     f.close()
@@ -219,12 +289,12 @@ class SystemController:
                     for nic, addrs in ethernet.items():
                         if nic == "eth0":
                             for addr in addrs:
-                                if str(addr.family) == "AddressFamily.AF_INET": 
+                                if str(addr.family) == "AddressFamily.AF_INET" or str(addr.family) == "2": 
                                     if addr.address:
                                         eth0IP = addr.address
                         if nic == "wlan0":
                             for addr in addrs:
-                                if str(addr.family) == "AddressFamily.AF_INET": 
+                                if str(addr.family) == "AddressFamily.AF_INET" or str(addr.family) == "2": 
                                     if addr.address:
                                         wlan0IP = addr.address
                     info = psutil.net_if_stats()
