@@ -46,6 +46,8 @@ class FermenterAutostart(CBPiExtension):
              Property.Number(label="HeaterOffsetOff", configurable=True, description="Offset as decimal number when the heater is switched off. Should be smaller then 'HeaterOffsetOn'. For example a value of 1 switches off the heater if the current temperature is 1 degree below the target temperature"),
              Property.Number(label="CoolerOffsetOn", configurable=True, description="Offset as decimal number when the cooler is switched on. Should be greater then 'CoolerOffsetOff'. For example a value of 2 switches on the cooler if the current temperature is 2 degrees above the target temperature"),
              Property.Number(label="CoolerOffsetOff", configurable=True, description="Offset as decimal number when the cooler is switched off. Should be smaller then 'CoolerOffsetOn'. For example a value of 1 switches off the cooler if the current temperature is 1 degree above the target temperature"),
+             Property.Number(label="HeaterMaxPower", configurable=True,description="Max Power [%] for Heater (default: 100)"),
+             Property.Number(label="CoolerMaxPower", configurable=True ,description="Max Power [%] for Cooler (default: 100)"),
              Property.Select(label="AutoStart", options=["Yes","No"],description="Autostart Fermenter on cbpi start"),
              Property.Sensor(label="sensor2",description="Optional Sensor for LCDisplay(e.g. iSpindle)")])
 
@@ -53,11 +55,13 @@ class FermenterHysteresis(CBPiFermenterLogic):
     
     async def run(self):
         try:
-            self.heater_offset_min = float(self.props.get("HeaterOffsetOn", 0))
+            self.heater_offset_min = float(self.props.get("HeaterOffsetOn", 0.2))
             self.heater_offset_max = float(self.props.get("HeaterOffsetOff", 0))
-            self.cooler_offset_min = float(self.props.get("CoolerOffsetOn", 0))
+            self.cooler_offset_min = float(self.props.get("CoolerOffsetOn", 0.2))
             self.cooler_offset_max = float(self.props.get("CoolerOffsetOff", 0))
-        
+            self.heater_max_power = int(self.props.get("HeaterMaxPower", 100))
+            self.cooler_max_power = int(self.props.get("CoolerMaxPower", 100))
+            
             self.fermenter = self.get_fermenter(self.id)
             self.heater = self.fermenter.heater
             self.cooler = self.fermenter.cooler
@@ -81,7 +85,7 @@ class FermenterHysteresis(CBPiFermenterLogic):
 
                 if sensor_value + self.heater_offset_min <= target_temp:
                     if self.heater and (heater_state == False):
-                        await self.actor_on(self.heater)
+                        await self.actor_on(self.heater, self.heater_max_power)
                     
                 if sensor_value + self.heater_offset_max >= target_temp:
                     if self.heater and (heater_state == True):
@@ -89,7 +93,7 @@ class FermenterHysteresis(CBPiFermenterLogic):
 
                 if sensor_value >=  self.cooler_offset_min + target_temp:
                     if self.cooler and (cooler_state == False):
-                        await self.actor_on(self.cooler)
+                        await self.actor_on(self.cooler, self.cooler_max_power)
                     
                 if sensor_value <= self.cooler_offset_max + target_temp:
                     if self.cooler and (cooler_state == True):
@@ -149,9 +153,9 @@ class FermenterSpundingHysteresis(CBPiFermenterLogic):
             logging.info("No valve or pressure sensor defined")
 
     async def temperature_control(self):
-            self.heater_offset_min = float(self.props.get("HeaterOffsetOn", 0))
+            self.heater_offset_min = float(self.props.get("HeaterOffsetOn", 0.2))
             self.heater_offset_max = float(self.props.get("HeaterOffsetOff", 0))
-            self.cooler_offset_min = float(self.props.get("CoolerOffsetOn", 0))
+            self.cooler_offset_min = float(self.props.get("CoolerOffsetOn", 0.2))
             self.cooler_offset_max = float(self.props.get("CoolerOffsetOff", 0))
         
             heater = self.cbpi.actor.find_by_id(self.heater)
