@@ -37,4 +37,18 @@ class NotificationHttpEndpoints:
         action_id = request.match_info['action_id']
         #print(notification_id, action_id)
         self.cbpi.notification.notify_callback(notification_id, action_id)  
-        return web.Response(status=204)
\ No newline at end of file
+        return web.Response(status=200)
+    
+    @request_mapping("/delete", method="POST", auth_required=False)
+    async def restart(self, request):
+        """
+        ---
+        description: DeleteNotifications
+        tags:
+        - Notification
+        responses:
+            "200":
+                description: successful operation
+        """
+        self.cbpi.notification.delete_all_notifications()
+        return web.Response(status=200)
\ No newline at end of file
