@@ -1,5 +1,7 @@
+from cbpi.api.dataclasses import Props, Sensor
 from aiohttp import web
 from cbpi.api import *
+import logging
 auth = False
 
 class SensorHttpEndpoints():
@@ -57,9 +59,10 @@ class SensorHttpEndpoints():
                 description: successful operation
         """
         data = await request.json()
-        response_data = await self.controller.add(data)
+        sensor = Sensor(name=data.get("name"), props=Props(data.get("props", {})), type=data.get("type"))
+        response_data = await self.controller.add(sensor)
 
-        return web.json_response(data=self.controller.create_dict(response_data))
+        return web.json_response(data=response_data.to_dict())
         
 
     @request_mapping(path="/{id}", method="PUT", auth_required=False)
@@ -95,7 +98,8 @@ class SensorHttpEndpoints():
         """
         id = request.match_info['id']
         data = await request.json()
-        return web.json_response(data=self.controller.create_dict(await self.controller.update(id, data)))
+        sensor = Sensor(id=id, name=data.get("name"), props=Props(data.get("props", {})), type=data.get("type"))
+        return web.json_response(data=(await self.controller.update(sensor)).to_dict())
     
     @request_mapping(path="/{id}", method="DELETE", auth_required=False)
     async def http_delete_one(self, request):
@@ -168,25 +172,44 @@ class SensorHttpEndpoints():
         await self.controller.off(id)
         return web.Response(status=204)
     
+    @request_mapping(path="/{id}", method="GET", auth_required=False)
+    async def get_value(self, request):
+        """
+
+        ---
+        description: Get Sensor Value 
+        tags:
+        - Sensor
+        parameters:
+        - name: "id"
+          in: "path"
+          description: "Sensor ID"
+          type: "string"
+          required: true
+        """
+        id = request.match_info['id']
+        sensor_value = self.controller.get_sensor_value(id)
+        logging.info(sensor_value)
+        return web.json_response(data=sensor_value)
 
     @request_mapping(path="/{id}/action", method="POST", auth_required=auth)
     async def http_action(self, request) -> web.Response:
         """
 
         ---
-        description: Toogle an actor on or off
+        description: Call Action for Sensor 
         tags:
         - Sensor
         parameters:
         - name: "id"
           in: "path"
-          description: "Actor ID"
+          description: "Sensor ID"
           required: true
           type: "integer"
           format: "int64"
         - in: body
           name: body
-          description: Update an actor
+          description: Call an action for a Sensor
           required: false
           schema:
             type: object
@@ -199,8 +222,9 @@ class SensorHttpEndpoints():
             "204":
                 description: successful operation
         """
-        actor_id = request.match_info['id']
+        sensor_id = request.match_info['id']
         data = await request.json()
-        await self.controller.call_action(actor_id, data.get("name"), data.get("parameter"))
+        #print(data)
+        await self.controller.call_action(sensor_id, data.get("action"), data.get("parameter"))
 
-        return web.Response(status=204)
\ No newline at end of file
+        return web.Response(status=204)
