@@ -42,6 +42,8 @@ class SystemHttpEndpoints:
             step=self.cbpi.step.get_state(),
             fermentersteps=self.cbpi.fermenter.get_fermenter_steps(),
             config=self.cbpi.config.get_state(),
+            notifications=self.cbpi.notification.get_state(),
+            bf_recipes=await self.cbpi.upload.get_brewfather_recipes(0),
             version=__version__,
             guiversion=version,
             codename=__codename__)
@@ -140,10 +142,10 @@ class SystemHttpEndpoints:
                 content:  # Response body
                 application/zip:  # Media type
         """
-        await self.controller.backupConfig()
-        filename = "cbpi4_config.zip"
+        filename = await self.controller.backupConfig()
+        #filename = "cbpi4_config.zip"
         file_name = pathlib.Path(os.path.join(".", filename))
-
+        
         response = web.StreamResponse(
             status=200,
             reason='OK',
@@ -165,31 +167,49 @@ class SystemHttpEndpoints:
         description: Zip and download craftbeerpi.service log 
         tags:
         - System
+        parameters:
+        - name: "logtime"
+          in: "path"
+          description: "Logtime in hours"
+          required: true
+          type: "integer"
+          format: "int64"
         responses:
             "200":
                 description: successful operation
                 content:  # Response body
                 application/zip:  # Media type
         """
-        logtime = request.match_info['logtime']
-        await self.controller.downloadlog(logtime)
-        filename = "cbpi4_log.zip"
-        file_name = pathlib.Path(os.path.join(".", filename))
+        checklogtime = False
+        logtime = request.match_info['logtime']      
+        
+        try:
+            test=int(logtime)
+            checklogtime = True
+        except:
+            if logtime == "b":
+                checklogtime = True
 
-        response = web.StreamResponse(
-            status=200,
-            reason='OK',
-            headers={'Content-Type': 'application/zip'},
-        )
-        await response.prepare(request)
-        with open(file_name, 'rb') as file:
-            for line in file.readlines():
-                await response.write(line)
+        if checklogtime:
+            await self.controller.downloadlog(logtime)
+            filename = "cbpi4_log.zip"
+            file_name = pathlib.Path(os.path.join(".", filename))
 
-        await response.write_eof()
-        os.remove(file_name)
-        return response
+            response = web.StreamResponse(
+                status=200,
+                reason='OK',
+                headers={'Content-Type': 'application/zip'},
+            )
+            await response.prepare(request)
+            with open(file_name, 'rb') as file:
+                for line in file.readlines():
+                    await response.write(line)
 
+            await response.write_eof()
+            os.remove(file_name)
+            return response
+        else:
+            return web.Response(status=400, text='Need integer or "b" for logtime.')
 
     @request_mapping("/restore", method="POST", name="RestoreConfig", auth_required=False)
     async def restore(self, request):
