@@ -15,13 +15,6 @@ except Exception:
     patcher.start()
     import RPi.GPIO as GPIO
 
-
-class HelloWorld(object):
-
-    def test(self, a):
-        return a
-
-
 class TestSwitch(unittest.TestCase):
 
     GPIO_NUM = 22
@@ -35,15 +28,4 @@ class TestSwitch(unittest.TestCase):
     @patch("RPi.GPIO.output")
     def test_switch_without_scheduler_starts_disabled(self, patched_output):
         GPIO.output(self.GPIO_NUM, GPIO.LOW)
-        patched_output.assert_called_once_with(self.GPIO_NUM, GPIO.LOW)
-
-
-    def test_hello_world(self):
-        h = HelloWorld()
-        with mock.patch.object(HelloWorld, 'test', wraps=h.test) as fake_increment:
-            #print(h.test("HALLO"))
-            print(h.test("ABC"))
-            print(fake_increment.call_args)
-            print(h.test("HALLO"))
-            print(fake_increment.call_args_list)
-
+        patched_output.assert_called_once_with(self.GPIO_NUM, GPIO.LOW)
\ No newline at end of file
